==> plugin.video.fen-2.0.14.zip: plugin.video.fen/resources/lib/modules/history.py <==
# -*- coding: utf-8 -*-

from sys import argv
from datetime import timedelta
from caches import fen_cache
from modules.kodi_utils import execute_builtin, translate_path, notification, setView
from modules.utils import local_string as ls
# from modules.utils import logger

icon = translate_path('special://home/addons/script.tikiart/resources/media/search.png')
fanart = translate_path('special://home/addons/plugin.video.fen/fanart.png')
_cache = fen_cache.FenCache()

def add_to_search_history(search_name, search_list):
	try:
		result = []
		cache = _cache.get(search_list)
		if cache: result = cache
		if search_name in result: result.remove(search_name)
		result.insert(0, search_name)
		result = result[:10]
		_cache.set(search_list, result, expiration=timedelta(days=365))
	except: return

def remove_from_history(params):
	try:
		result = _cache.get(params['setting_id'])
		result.remove(params.get('name'))
		_cache.set(params['setting_id'], result, expiration=timedelta(days=365))
		notification(ls(32576), 3500)
		execute_builtin('Container.Refresh')
	except: return

def clear_search_history():
	import json
	from modules.utils import select_dialog
	delete_str, search_str, hist_str, vid_str, mov_str = ls(32785), ls(32450), ls(32486), ls(32491), ls(32028)
	tv_str, aud_str, furk_str, easy_str, peop_str = ls(32029), ls(32492), ls(32069), ls(32070), ls(32507)
	choice_list = [('%s %s %s %s' % (delete_str, mov_str, search_str, hist_str), 'movie_queries', 'Movie'),
				   ('%s %s %s %s' % (delete_str, tv_str, search_str, hist_str), 'tvshow_queries', 'TV Show'), 
				   ('%s %s %s %s' % (delete_str, peop_str, search_str, hist_str), 'people_queries', 'People'),
				   ('%s %s %s %s %s' % (delete_str, furk_str, vid_str, search_str, hist_str), 'furk_video_queries', 'Furk Video'), 
				   ('%s %s %s %s %s' % (delete_str, furk_str, aud_str, search_str, hist_str), 'furk_audio_queries', 'Furk Audio'), 
				   ('%s %s %s %s' % (delete_str, easy_str, search_str, hist_str), 'easynews_video_queries', 'Easynews Video')]
	try:
		list_items = [{'line1': item[0], 'icon': icon} for item in choice_list]
		kwargs = {'items': json.dumps(list_items), 'heading': 'Fen', 'enumerate': 'false', 'multi_choice': 'false', 'multi_line': 'false'}
		setting = select_dialog([item[1] for item in choice_list], **kwargs)
		if setting == None: return
		_cache.set(setting, '', expiration=timedelta(days=365))
		notification(ls(32576), 3500)
	except: return

def search_history(params):
	import xbmcgui, xbmcplugin
	try: from urllib import unquote
	except ImportError: from urllib.parse import unquote
	from modules.nav_utils import build_url
	sear_str = ls(32450).upper()
	mov_str = ls(32028).upper()
	tv_str = ls(32029).upper()
	peop_str = ls(32507).upper()
	furkvid_str = '%s %s' % (ls(32069).upper(), ls(32491).upper())
	furkaud_str = '%s %s' % (ls(32069).upper(), ls(32492).upper())
	remove_str = ls(32786)
	easy_str = ls(32070).upper()
	action = params['action']
	try:
		(search_setting, display_title) = ('movie_queries', mov_str) if action == 'movie' \
									 else ('tvshow_queries', tv_str) if action == 'tvshow' \
									 else ('people_queries', peop_str) if action == 'people' \
									 else ('furk_video_queries', furkvid_str) if action == 'furk_video' \
									 else ('furk_audio_queries', furkaud_str) if action == 'furk_audio' \
									 else ('easynews_video_queries', easy_str) if action == 'easynews_video' \
									 else ''
		history = _cache.get(search_setting)
		if not history: return
	except: return
	for h in history:
		try:
			cm = []
			name = unquote(h)
			url_params = {'mode': 'get_search_term', 'db_type': 'movie', 'query': name} if action == 'movie' \
					else {'mode': 'get_search_term', 'db_type': 'tv_show', 'query': name} if action == 'tvshow' \
					else {'mode': 'people_search.search', 'actor_name': name} if action == 'people' \
					else {'mode': 'furk.search_furk', 'db_type': 'video', 'query': name} if action == 'furk_video' \
					else {'mode': 'furk.search_furk', 'db_type': 'audio', 'music': True, 'query': name} if action == 'furk_audio' \
					else {'mode': 'easynews.search_easynews', 'query': name} if action == 'easynews_video' \
					else ''
			isFolder = False if action in ('movie', 'tvshow', 'people') else True
			display = '[B]%s %s : [/B]' % (display_title, sear_str) + name 
			url = build_url(url_params)
			cm.append((remove_str,'RunPlugin(%s)' % build_url({'mode': 'remove_from_history', 'setting_id':search_setting, 'name': name})))
			listitem = xbmcgui.ListItem(display)
			listitem.setArt({'icon': icon, 'poster': icon, 'thumb': icon, 'fanart': fanart, 'banner': icon})
			listitem.addContextMenuItems(cm)
			xbmcplugin.addDirectoryItem(int(argv[1]), url, listitem, isFolder=isFolder)
		except: pass
	xbmcplugin.setContent(int(argv[1]), '')
	xbmcplugin.endOfDirectory(int(argv[1]))
	setView('view.main', '')

==> plugin.video.fen-2.0.26.zip: plugin.video.fen/resources/lib/modules/history.py <==
# -*- coding: utf-8 -*-
from sys import argv
from datetime import timedelta
from caches import fen_cache
from modules.kodi_utils import execute_builtin, translate_path, notification, setView, select_dialog, local_string as ls
# from modules.utils import logger

icon = translate_path('special://home/addons/script.tikiart/resources/media/search.png')
fanart = translate_path('special://home/addons/plugin.video.fen/fanart.png')
_cache = fen_cache.FenCache()

def add_to_search_history(search_name, search_list):
	try:
		result = []
		cache = _cache.get(search_list)
		if cache: result = cache
		if search_name in result: result.remove(search_name)
		result.insert(0, search_name)
		result = result[:10]
		_cache.set(search_list, result, expiration=timedelta(days=365))
	except: return

def remove_from_history(params):
	try:
		result = _cache.get(params['setting_id'])
		result.remove(params.get('name'))
		_cache.set(params['setting_id'], result, expiration=timedelta(days=365))
		notification(ls(32576), 3500)
		execute_builtin('Container.Refresh')
	except: return

def clear_search_history():
	import json
	delete_str, search_str, hist_str, vid_str, mov_str = ls(32785), ls(32450), ls(32486), ls(32491), ls(32028)
	tv_str, aud_str, furk_str, easy_str, peop_str = ls(32029), ls(32492), ls(32069), ls(32070), ls(32507)
	choice_list = [('%s %s %s %s' % (delete_str, mov_str, search_str, hist_str), 'movie_queries', 'Movie'),
				   ('%s %s %s %s' % (delete_str, tv_str, search_str, hist_str), 'tvshow_queries', 'TV Show'), 
				   ('%s %s %s %s' % (delete_str, peop_str, search_str, hist_str), 'people_queries', 'People'),
				   ('%s %s %s %s %s' % (delete_str, furk_str, vid_str, search_str, hist_str), 'furk_video_queries', 'Furk Video'), 
				   ('%s %s %s %s %s' % (delete_str, furk_str, aud_str, search_str, hist_str), 'furk_audio_queries', 'Furk Audio'), 
				   ('%s %s %s %s' % (delete_str, easy_str, search_str, hist_str), 'easynews_video_queries', 'Easynews Video')]
	try:
		list_items = [{'line1': item[0], 'icon': icon} for item in choice_list]
		kwargs = {'items': json.dumps(list_items), 'heading': 'Fen', 'enumerate': 'false', 'multi_choice': 'false', 'multi_line': 'false'}
		setting = select_dialog([item[1] for item in choice_list], **kwargs)
		if setting == None: return
		_cache.set(setting, '', expiration=timedelta(days=365))
		notification(32576, 3500)
	except: return

def search_history(params):
	import xbmcgui, xbmcplugin
	try: from urllib import unquote
	except ImportError: from urllib.parse import unquote
	from modules.nav_utils import build_url
	sear_str = ls(32450).upper()
	mov_str = ls(32028).upper()
	tv_str = ls(32029).upper()
	peop_str = ls(32507).upper()
	furkvid_str = '%s %s' % (ls(32069).upper(), ls(32491).upper())
	furkaud_str = '%s %s' % (ls(32069).upper(), ls(32492).upper())
	remove_str = ls(32786)
	easy_str = ls(32070).upper()
	action = params['action']
	try:
		(search_setting, display_title) = ('movie_queries', mov_str) if action == 'movie' \
									 else ('tvshow_queries', tv_str) if action == 'tvshow' \
									 else ('people_queries', peop_str) if action == 'people' \
									 else ('furk_video_queries', furkvid_str) if action == 'furk_video' \
									 else ('furk_audio_queries', furkaud_str) if action == 'furk_audio' \
									 else ('easynews_video_queries', easy_str) if action == 'easynews_video' \
									 else ''
		history = _cache.get(search_setting)
		if not history: return
	except: return
	for h in history:
		try:
			cm = []
			name = unquote(h)
			url_params = {'mode': 'get_search_term', 'db_type': 'movie', 'query': name} if action == 'movie' \
					else {'mode': 'get_search_term', 'db_type': 'tv_show', 'query': name} if action == 'tvshow' \
					else {'mode': 'people_search.search', 'actor_name': name} if action == 'people' \
					else {'mode': 'furk.search_furk', 'db_type': 'video', 'query': name} if action == 'furk_video' \
					else {'mode': 'furk.search_furk', 'db_type': 'audio', 'music': True, 'query': name} if action == 'furk_audio' \
					else {'mode': 'easynews.search_easynews', 'query': name} if action == 'easynews_video' \
					else ''
			isFolder = False if action in ('movie', 'tvshow', 'people') else True
			display = '[B]%s %s : [/B]' % (display_title, sear_str) + name 
			url = build_url(url_params)
			cm.append((remove_str,'RunPlugin(%s)' % build_url({'mode': 'remove_from_history', 'setting_id':search_setting, 'name': name})))
			listitem = xbmcgui.ListItem(display)
			listitem.setArt({'icon': icon, 'poster': icon, 'thumb': icon, 'fanart': fanart, 'banner': icon})
			listitem.addContextMenuItems(cm)
			xbmcplugin.addDirectoryItem(int(argv[1]), url, listitem, isFolder=isFolder)
		except: pass
	xbmcplugin.setContent(int(argv[1]), '')
	xbmcplugin.endOfDirectory(int(argv[1]))
	setView('view.main', '')
